@@ -1,4 +1,5 @@
 from __future__ import annotations
+
 from dask_gateway_server.options import Options, Select
 
 from aws_pcluster_helpers.models.sinfo import (SInfoTable, SinfoRow)
@@ -6,7 +7,7 @@ import functools
 import os
 
 from jinja2 import Environment, BaseLoader
-from pydantic.dataclasses import dataclass
+# from pydantic.dataclasses import dataclass
 import dataclasses
 from typing import List, Any, TypedDict, Dict, Optional
 from typing import ForwardRef
@@ -52,7 +53,7 @@ https://gateway.dask.org/install-jobqueue.html
 """
 
 
-@dataclass
+@dataclasses.dataclass
 class DaskGatewaySlurmConfig(sinfo.SInfoTable):
     @functools.cached_property
     def profiles(self):
